@@ -57,7 +57,9 @@ PLAIN_COLUMNS = 12
 MARKDOWN = 13
 ORGMODE = 14
 DOUBLE_BORDER = 15
+SINGLE_BORDER = 16
 RANDOM = 20
+BASE_ALIGN_VALUE = "base_align_value"
 
 _re = re.compile(r"\033\[[0-9;]*m|\033\(B")
 
@@ -71,7 +73,6 @@ def _get_size(text):
 
 class PrettyTable:
     def __init__(self, field_names=None, **kwargs):
-
         """Return a new PrettyTable instance
 
         Arguments:
@@ -86,6 +87,8 @@ class PrettyTable:
         header_style - stylisation to apply to field names in header
             ("cap", "title", "upper", "lower" or None)
         border - print a border around the table (True or False)
+        preserve_internal_border - print a border inside the table even if
+            border is disabled (True or False)
         hrules - controls printing of horizontal rules after rows.
             Allowed values: FRAME, HEADER, ALL, NONE
         vrules - controls printing of vertical rules between columns.
@@ -103,6 +106,7 @@ class PrettyTable:
         right_padding_width - number of spaces on right hand side of column data
         vertical_char - single character string used to draw vertical lines
         horizontal_char - single character string used to draw horizontal lines
+        horizontal_align_char - single character string used to indicate alignment
         junction_char - single character string used to draw line junctions
         top_junction_char - single character string used to draw top line junctions
         bottom_junction_char -
@@ -150,6 +154,7 @@ class PrettyTable:
             "fields",
             "header",
             "border",
+            "preserve_internal_border",
             "sortby",
             "reversesort",
             "sort_key",
@@ -167,6 +172,7 @@ class PrettyTable:
             "right_padding_width",
             "vertical_char",
             "horizontal_char",
+            "horizontal_align_char",
             "junction_char",
             "header_style",
             "valign",
@@ -185,6 +191,7 @@ class PrettyTable:
             "valign",
             "max_width",
             "min_width",
+            "none_format",
         ]
         for option in self._options:
             if option in kwargs:
@@ -196,6 +203,7 @@ class PrettyTable:
         self._start = kwargs["start"] or 0
         self._end = kwargs["end"] or None
         self._fields = kwargs["fields"] or None
+        self._none_format = {}
 
         if kwargs["header"] in (True, False):
             self._header = kwargs["header"]
@@ -206,6 +214,10 @@ class PrettyTable:
             self._border = kwargs["border"]
         else:
             self._border = True
+        if kwargs["preserve_internal_border"] in (True, False):
+            self._preserve_internal_border = kwargs["preserve_internal_border"]
+        else:
+            self._preserve_internal_border = False
         self._hrules = kwargs["hrules"] or FRAME
         self._vrules = kwargs["vrules"] or ALL
 
@@ -224,6 +236,7 @@ class PrettyTable:
         self.int_format = kwargs["int_format"] or {}
         self.float_format = kwargs["float_format"] or {}
         self.custom_format = kwargs["custom_format"] or {}
+        self.none_format = kwargs["none_format"] or {}
 
         self._min_table_width = kwargs["min_table_width"] or None
         self._max_table_width = kwargs["max_table_width"] or None
@@ -236,6 +249,7 @@ class PrettyTable:
 
         self._vertical_char = kwargs["vertical_char"] or "|"
         self._horizontal_char = kwargs["horizontal_char"] or "-"
+        self._horizontal_align_char = kwargs["horizontal_align_char"]
         self._junction_char = kwargs["junction_char"] or "+"
         self._top_junction_char = kwargs["top_junction_char"]
         self._bottom_junction_char = kwargs["bottom_junction_char"]
@@ -306,7 +320,7 @@ class PrettyTable:
         elif isinstance(index, int):
             new.add_row(self._rows[index])
         else:
-            raise Exception(f"Index {index} is invalid, must be an integer or slice")
+            raise IndexError(f"Index {index} is invalid, must be an integer or slice")
         return new
 
     def __str__(self):
@@ -338,6 +352,8 @@ class PrettyTable:
     def _validate_option(self, option, val):
         if option == "field_names":
             self._validate_field_names(val)
+        elif option == "none_format":
+            self._validate_none_format(val)
         elif option in (
             "start",
             "end",
@@ -364,6 +380,7 @@ class PrettyTable:
         elif option in (
             "header",
             "border",
+            "preserve_internal_border",
             "reversesort",
             "xhtml",
             "print_empty",
@@ -382,6 +399,7 @@ class PrettyTable:
         elif option in (
             "vertical_char",
             "horizontal_char",
+            "horizontal_align_char",
             "junction_char",
             "top_junction_char",
             "bottom_junction_char",
@@ -402,7 +420,7 @@ class PrettyTable:
             try:
                 assert len(val) == len(self._field_names)
             except AssertionError:
-                raise Exception(
+                raise ValueError(
                     "Field name list has incorrect number of values, "
                     f"(actual) {len(val)}!={len(self._field_names)} (expected)"
                 )
@@ -410,7 +428,7 @@ class PrettyTable:
             try:
                 assert len(val) == len(self._rows[0])
             except AssertionError:
-                raise Exception(
+                raise ValueError(
                     "Field name list has incorrect number of values, "
                     f"(actual) {len(val)}!={len(self._rows[0])} (expected)"
                 )
@@ -418,13 +436,22 @@ class PrettyTable:
         try:
             assert len(val) == len(set(val))
         except AssertionError:
-            raise Exception("Field names must be unique")
+            raise ValueError("Field names must be unique")
+
+    def _validate_none_format(self, val):
+        try:
+            if val is not None:
+                assert isinstance(val, str)
+        except AssertionError:
+            raise TypeError(
+                "Replacement for None value must be a string if being supplied."
+            )
 
     def _validate_header_style(self, val):
         try:
             assert val in ("cap", "title", "upper", "lower", None)
         except AssertionError:
-            raise Exception(
+            raise ValueError(
                 "Invalid header style, use cap, title, upper, lower or None"
             )
 
@@ -432,25 +459,25 @@ class PrettyTable:
         try:
             assert val in ["l", "c", "r"]
         except AssertionError:
-            raise Exception(f"Alignment {val} is invalid, use l, c or r")
+            raise ValueError(f"Alignment {val} is invalid, use l, c or r")
 
     def _validate_valign(self, val):
         try:
             assert val in ["t", "m", "b", None]
         except AssertionError:
-            raise Exception(f"Alignment {val} is invalid, use t, m, b or None")
+            raise ValueError(f"Alignment {val} is invalid, use t, m, b or None")
 
     def _validate_nonnegative_int(self, name, val):
         try:
             assert int(val) >= 0
         except AssertionError:
-            raise Exception(f"Invalid value for {name}: {val}")
+            raise ValueError(f"Invalid value for {name}: {val}")
 
     def _validate_true_or_false(self, name, val):
         try:
             assert val in (True, False)
         except AssertionError:
-            raise Exception(f"Invalid value for {name}. Must be True or False.")
+            raise ValueError(f"Invalid value for {name}. Must be True or False.")
 
     def _validate_int_format(self, name, val):
         if val == "":
@@ -459,7 +486,7 @@ class PrettyTable:
             assert isinstance(val, str)
             assert val.isdigit()
         except AssertionError:
-            raise Exception(
+            raise ValueError(
                 f"Invalid value for {name}. Must be an integer format string."
             )
 
@@ -478,19 +505,21 @@ class PrettyTable:
                 or (bits[1][-1] == "f" and bits[1].rstrip("f").isdigit())
             )
         except AssertionError:
-            raise Exception(f"Invalid value for {name}. Must be a float format string.")
+            raise ValueError(
+                f"Invalid value for {name}. Must be a float format string."
+            )
 
     def _validate_function(self, name, val):
         try:
             assert hasattr(val, "__call__")
         except AssertionError:
-            raise Exception(f"Invalid value for {name}. Must be a function.")
+            raise ValueError(f"Invalid value for {name}. Must be a function.")
 
     def _validate_hrules(self, name, val):
         try:
             assert val in (ALL, FRAME, HEADER, NONE)
         except AssertionError:
-            raise Exception(
+            raise ValueError(
                 f"Invalid value for {name}. Must be ALL, FRAME, HEADER or NONE."
             )
 
@@ -498,36 +527,39 @@ class PrettyTable:
         try:
             assert val in (ALL, FRAME, NONE)
         except AssertionError:
-            raise Exception(f"Invalid value for {name}. Must be ALL, FRAME, or NONE.")
+            raise ValueError(f"Invalid value for {name}. Must be ALL, FRAME, or NONE.")
 
     def _validate_field_name(self, name, val):
         try:
             assert (val in self._field_names) or (val is None)
         except AssertionError:
-            raise Exception(f"Invalid field name: {val}")
+            raise ValueError(f"Invalid field name: {val}")
 
     def _validate_all_field_names(self, name, val):
         try:
             for x in val:
                 self._validate_field_name(name, x)
         except AssertionError:
-            raise Exception("Fields must be a sequence of field names")
+            raise ValueError("Fields must be a sequence of field names")
 
     def _validate_single_char(self, name, val):
         try:
             assert _str_block_width(val) == 1
         except AssertionError:
-            raise Exception(f"Invalid value for {name}. Must be a string of length 1.")
+            raise ValueError(f"Invalid value for {name}. Must be a string of length 1.")
 
     def _validate_attributes(self, name, val):
         try:
             assert isinstance(val, dict)
         except AssertionError:
-            raise Exception("Attributes must be a dictionary of name/value pairs")
+            raise TypeError("Attributes must be a dictionary of name/value pairs")
 
     ##############################
     # ATTRIBUTE MANAGEMENT       #
     ##############################
+    @property
+    def rows(self):
+        return self._rows[:]
 
     @property
     def xhtml(self):
@@ -539,6 +571,22 @@ class PrettyTable:
         self._validate_option("xhtml", val)
         self._xhtml = val
 
+    @property
+    def none_format(self):
+        return self._none_format
+
+    @none_format.setter
+    def none_format(self, val):
+        if not self._field_names:
+            self._none_format = {}
+        elif val is None or (isinstance(val, dict) and len(val) == 0):
+            for field in self._field_names:
+                self._none_format[field] = None
+        else:
+            self._validate_none_format(val)
+            for field in self._field_names:
+                self._none_format[field] = val
+
     @property
     def field_names(self):
         """List or tuple of field names
@@ -562,6 +610,9 @@ class PrettyTable:
             for old_name in old_names:
                 if old_name not in self._align:
                     self._align.pop(old_name)
+        elif self._align:
+            for field_name in self._field_names:
+                self._align[field_name] = self._align[BASE_ALIGN_VALUE]
         else:
             self.align = "c"
         if self._valign and old_names:
@@ -583,15 +634,19 @@ class PrettyTable:
 
     @align.setter
     def align(self, val):
-        if not self._field_names:
-            self._align = {}
-        elif val is None or (isinstance(val, dict) and len(val) == 0):
-            for field in self._field_names:
-                self._align[field] = "c"
+        if val is None or (isinstance(val, dict) and len(val) == 0):
+            if not self._field_names:
+                self._align = {BASE_ALIGN_VALUE: "c"}
+            else:
+                for field in self._field_names:
+                    self._align[field] = "c"
         else:
             self._validate_align(val)
-            for field in self._field_names:
-                self._align[field] = val
+            if not self._field_names:
+                self._align = {BASE_ALIGN_VALUE: val}
+            else:
+                for field in self._field_names:
+                    self._align[field] = val
 
     @property
     def valign(self):
@@ -803,6 +858,21 @@ class PrettyTable:
         self._validate_option("border", val)
         self._border = val
 
+    @property
+    def preserve_internal_border(self):
+        """Controls printing of border inside table
+
+        Arguments:
+
+        preserve_internal_border - print a border inside the table even if
+            border is disabled (True or False)"""
+        return self._preserve_internal_border
+
+    @preserve_internal_border.setter
+    def preserve_internal_border(self, val):
+        self._validate_option("preserve_internal_border", val)
+        self._preserve_internal_border = val
+
     @property
     def hrules(self):
         """Controls printing of horizontal rules after rows
@@ -886,7 +956,7 @@ class PrettyTable:
             for field in self._field_names:
                 self._custom_format[field] = val
         else:
-            raise Exception(
+            raise TypeError(
                 "The custom_format property need to be a dictionary or callable"
             )
 
@@ -962,6 +1032,21 @@ class PrettyTable:
         self._validate_option("horizontal_char", val)
         self._horizontal_char = val
 
+    @property
+    def horizontal_align_char(self):
+        """The character used to indicate column alignment in horizontal lines
+
+        Arguments:
+
+        horizontal_align_char - single character string used to indicate alignment"""
+        return self._bottom_left_junction_char or self.junction_char
+
+    @horizontal_align_char.setter
+    def horizontal_align_char(self, val):
+        val = str(val)
+        self._validate_option("horizontal_align_char", val)
+        self._horizontal_align_char = val
+
     @property
     def junction_char(self):
         """The character used when printing table borders to draw line junctions
@@ -1193,10 +1278,12 @@ class PrettyTable:
             self._set_orgmode_style()
         elif style == DOUBLE_BORDER:
             self._set_double_border_style()
+        elif style == SINGLE_BORDER:
+            self._set_single_border_style()
         elif style == RANDOM:
             self._set_random_style()
         else:
-            raise Exception("Invalid pre-set style")
+            raise ValueError("Invalid pre-set style")
 
     def _set_orgmode_style(self):
         self._set_default_style()
@@ -1211,6 +1298,7 @@ class PrettyTable:
         self.right_padding_width = 1
         self.vertical_char = "|"
         self.junction_char = "|"
+        self._horizontal_align_char = ":"
 
     def _set_default_style(self):
 
@@ -1223,6 +1311,7 @@ class PrettyTable:
         self.right_padding_width = 1
         self.vertical_char = "|"
         self.horizontal_char = "-"
+        self._horizontal_align_char = None
         self.junction_char = "+"
         self._top_junction_char = None
         self._bottom_junction_char = None
@@ -1264,6 +1353,19 @@ class PrettyTable:
         self.bottom_right_junction_char = "╝"
         self.bottom_left_junction_char = "╚"
 
+    def _set_single_border_style(self):
+        self.horizontal_char = "─"
+        self.vertical_char = "│"
+        self.junction_char = "┼"
+        self.top_junction_char = "┬"
+        self.bottom_junction_char = "┴"
+        self.right_junction_char = "┤"
+        self.left_junction_char = "├"
+        self.top_right_junction_char = "┐"
+        self.top_left_junction_char = "┌"
+        self.bottom_right_junction_char = "┘"
+        self.bottom_left_junction_char = "└"
+
     def _set_random_style(self):
 
         # Just for fun!
@@ -1276,6 +1378,7 @@ class PrettyTable:
         self.vertical_char = random.choice(r"~!@#$%^&*()_+|-=\{}[];':\",./;<>?")
         self.horizontal_char = random.choice(r"~!@#$%^&*()_+|-=\{}[];':\",./;<>?")
         self.junction_char = random.choice(r"~!@#$%^&*()_+|-=\{}[];':\",./;<>?")
+        self.preserve_internal_border = random.choice((True, False))
 
     ##############################
     # DATA INPUT METHODS         #
@@ -1302,7 +1405,7 @@ class PrettyTable:
         has fields"""
 
         if self._field_names and len(row) != len(self._field_names):
-            raise Exception(
+            raise ValueError(
                 "Row has incorrect number of values, "
                 f"(actual) {len(row)}!={len(self._field_names)} (expected)"
             )
@@ -1319,7 +1422,7 @@ class PrettyTable:
         row_index - The index of the row you want to delete.  Indexing starts at 0."""
 
         if row_index > len(self._rows) - 1:
-            raise Exception(
+            raise IndexError(
                 f"Can't delete row at index {row_index}, "
                 f"table only has {len(self._rows)} rows"
             )
@@ -1350,7 +1453,7 @@ class PrettyTable:
                     self._rows.append([])
                 self._rows[i].append(column[i])
         else:
-            raise Exception(
+            raise ValueError(
                 f"Column length {len(column)} does not match number of rows "
                 f"{len(self._rows)}"
             )
@@ -1374,7 +1477,7 @@ class PrettyTable:
         fieldname - The field name of the column you want to delete."""
 
         if fieldname not in self._field_names:
-            raise Exception(
+            raise ValueError(
                 "Can't delete column %r which is not a field name of this table."
                 " Field names are: %s"
                 % (fieldname, ", ".join(map(repr, self._field_names)))
@@ -1439,6 +1542,9 @@ class PrettyTable:
         for row in rows:
             for index, value in enumerate(row):
                 fieldname = self.field_names[index]
+                if self.none_format.get(fieldname) is not None:
+                    if value == "None" or value is None:
+                        value = self.none_format.get(fieldname)
                 if fieldname in self.max_width:
                     widths[index] = max(
                         widths[index],
@@ -1544,6 +1650,8 @@ class PrettyTable:
         fields - names of fields (columns) to include
         header - print a header showing field names (True or False)
         border - print a border around the table (True or False)
+        preserve_internal_border - print a border inside the table even if
+            border is disabled (True or False)
         hrules - controls printing of horizontal rules after rows.
             Allowed values: ALL, FRAME, HEADER, NONE
         vrules - controls printing of vertical rules between columns.
@@ -1557,6 +1665,7 @@ class PrettyTable:
         right_padding_width - number of spaces on right hand side of column data
         vertical_char - single character string used to draw vertical lines
         horizontal_char - single character string used to draw horizontal lines
+        horizontal_align_char - single character string used to indicate alignment
         junction_char - single character string used to draw line junctions
         junction_char - single character string used to draw line junctions
         top_junction_char - single character string used to draw top line junctions
@@ -1638,7 +1747,7 @@ class PrettyTable:
 
     def _stringify_hrule(self, options, where=""):
 
-        if not options["border"]:
+        if not options["border"] and not options["preserve_internal_border"]:
             return ""
         lpad, rpad = self._get_padding_widths(options)
         if options["vrules"] in (ALL, FRAME):
@@ -1652,7 +1761,17 @@ class PrettyTable:
         for field, width in zip(self._field_names, self._widths):
             if options["fields"] and field not in options["fields"]:
                 continue
-            bits.append((width + lpad + rpad) * options["horizontal_char"])
+
+            line = (width + lpad + rpad) * options["horizontal_char"]
+
+            # If necessary, add column alignment characters (e.g. ":" for Markdown)
+            if self._horizontal_align_char:
+                if self._align[field] in ("l", "c"):
+                    line = self._horizontal_align_char + line[1:]
+                if self._align[field] in ("c", "r"):
+                    line = line[:-1] + self._horizontal_align_char
+
+            bits.append(line)
             if options["vrules"] == ALL:
                 bits.append(options[where + "junction_char"])
             else:
@@ -1660,6 +1779,10 @@ class PrettyTable:
         if options["vrules"] in (ALL, FRAME):
             bits.pop()
             bits.append(options[where + "right_junction_char"])
+
+        if options["preserve_internal_border"] and not options["border"]:
+            bits = bits[1:-1]
+
         return "".join(bits)
 
     def _stringify_title(self, title, options):
@@ -1675,7 +1798,9 @@ class PrettyTable:
                 lines.append(self._stringify_hrule(options, "top_"))
         bits = []
         endpoint = (
-            options["vertical_char"] if options["vrules"] in (ALL, FRAME) else " "
+            options["vertical_char"]
+            if options["vrules"] in (ALL, FRAME) and options["border"]
+            else " "
         )
         bits.append(endpoint)
         title = " " * lpad + title + " " * rpad
@@ -1721,22 +1846,32 @@ class PrettyTable:
                 fieldname = field.lower()
             else:
                 fieldname = field
+            if _str_block_width(fieldname) > width:
+                fieldname = fieldname[:width]
             bits.append(
                 " " * lpad
                 + self._justify(fieldname, width, self._align[field])
                 + " " * rpad
             )
-            if options["border"]:
+            if options["border"] or options["preserve_internal_border"]:
                 if options["vrules"] == ALL:
                     bits.append(options["vertical_char"])
                 else:
                     bits.append(" ")
+
+        # If only preserve_internal_border is true, then we just appended
+        # a vertical character at the end when we wanted a space
+        if not options["border"] and options["preserve_internal_border"]:
+            bits.pop()
+            bits.append(" ")
         # If vrules is FRAME, then we just appended a space at the end
         # of the last field, when we really want a vertical character
         if options["border"] and options["vrules"] == FRAME:
             bits.pop()
             bits.append(options["vertical_char"])
-        if options["border"] and options["hrules"] != NONE:
+        if (options["border"] or options["preserve_internal_border"]) and options[
+            "hrules"
+        ] != NONE:
             bits.append("\n")
             bits.append(self._hrule)
         return "".join(bits)
@@ -1750,6 +1885,8 @@ class PrettyTable:
             lines = value.split("\n")
             new_lines = []
             for line in lines:
+                if line == "None" and self.none_format.get(field) is not None:
+                    line = self.none_format[field]
                 if _str_block_width(line) > width:
                     line = textwrap.fill(line, width)
                 new_lines.append(line)
@@ -1800,13 +1937,19 @@ class PrettyTable:
                     + self._justify(line, width, self._align[field])
                     + " " * rpad
                 )
-                if options["border"]:
+                if options["border"] or options["preserve_internal_border"]:
                     if options["vrules"] == ALL:
                         bits[y].append(self.vertical_char)
                     else:
                         bits[y].append(" ")
                 y += 1
 
+        # If only preserve_internal_border is true, then we just appended
+        # a vertical character at the end when we wanted a space
+        if not options["border"] and options["preserve_internal_border"]:
+            bits[-1].pop()
+            bits[-1].append(" ")
+
         # If vrules is FRAME, then we just appended a space at the end
         # of the last field, when we really want a vertical character
         for y in range(0, row_height):
@@ -1908,6 +2051,8 @@ class PrettyTable:
         fields - names of fields (columns) to include
         header - print a header showing field names (True or False)
         border - print a border around the table (True or False)
+        preserve_internal_border - print a border inside the table even if
+            border is disabled (True or False)
         hrules - controls printing of horizontal rules after rows.
             Allowed values: ALL, FRAME, HEADER, NONE
         vrules - controls printing of vertical rules between columns.
@@ -1947,21 +2092,14 @@ class PrettyTable:
         open_tag = ["<table"]
         if options["attributes"]:
             for attr_name in options["attributes"]:
-                open_tag.append(
-                    ' {}="{}"'.format(attr_name, options["attributes"][attr_name])
-                )
+                open_tag.append(f' {attr_name}="{options["attributes"][attr_name]}"')
         open_tag.append(">")
         lines.append("".join(open_tag))
 
         # Title
         title = options["title"] or self._title
         if title:
-            cols = (
-                len(options["fields"]) if options["fields"] else len(self.field_names)
-            )
-            lines.append("    <tr>")
-            lines.append(f"        <td colspan={cols}>{title}</td>")
-            lines.append("    </tr>")
+            lines.append(f"    <caption>{title}</caption>")
 
         # Headers
         if options["header"]:
@@ -2019,23 +2157,18 @@ class PrettyTable:
                 open_tag.append(' frame="vsides"')
             elif options["vrules"] == ALL:
                 open_tag.append(' frame="vsides" rules="cols"')
+        if not options["border"] and options["preserve_internal_border"]:
+            open_tag.append(' rules="cols"')
         if options["attributes"]:
             for attr_name in options["attributes"]:
-                open_tag.append(
-                    ' {}="{}"'.format(attr_name, options["attributes"][attr_name])
-                )
+                open_tag.append(f' {attr_name}="{options["attributes"][attr_name]}"')
         open_tag.append(">")
         lines.append("".join(open_tag))
 
         # Title
         title = options["title"] or self._title
         if title:
-            cols = (
-                len(options["fields"]) if options["fields"] else len(self.field_names)
-            )
-            lines.append("    <tr>")
-            lines.append(f"        <td colspan={cols}>{title}</td>")
-            lines.append("    </tr>")
+            lines.append(f"    <caption>{title}</caption>")
 
         # Headers
         if options["header"]:
@@ -2102,6 +2235,8 @@ class PrettyTable:
         fields - names of fields (columns) to include
         header - print a header showing field names (True or False)
         border - print a border around the table (True or False)
+        preserve_internal_border - print a border inside the table even if
+            border is disabled (True or False)
         hrules - controls printing of horizontal rules after rows.
             Allowed values: ALL, FRAME, HEADER, NONE
         vrules - controls printing of vertical rules between columns.
@@ -2132,9 +2267,9 @@ class PrettyTable:
         else:
             wanted_fields = self._field_names
 
-        aligments = "".join([self._align[field] for field in wanted_fields])
+        alignments = "".join([self._align[field] for field in wanted_fields])
 
-        begin_cmd = "\\begin{tabular}{%s}" % aligments
+        begin_cmd = "\\begin{tabular}{%s}" % alignments
         lines.append(begin_cmd)
 
         # Headers
@@ -2165,25 +2300,28 @@ class PrettyTable:
         else:
             wanted_fields = self._field_names
 
-        wanted_aligments = [self._align[field] for field in wanted_fields]
+        wanted_alignments = [self._align[field] for field in wanted_fields]
         if options["border"] and options["vrules"] == ALL:
-            aligment_str = "|".join(wanted_aligments)
+            alignment_str = "|".join(wanted_alignments)
+        elif not options["border"] and options["preserve_internal_border"]:
+            alignment_str = "|".join(wanted_alignments)
         else:
-            aligment_str = "".join(wanted_aligments)
+            alignment_str = "".join(wanted_alignments)
 
         if options["border"] and options["vrules"] in [ALL, FRAME]:
-            aligment_str = "|" + aligment_str + "|"
+            alignment_str = "|" + alignment_str + "|"
 
-        begin_cmd = "\\begin{tabular}{%s}" % aligment_str
+        begin_cmd = "\\begin{tabular}{%s}" % alignment_str
         lines.append(begin_cmd)
-
         if options["border"] and options["hrules"] in [ALL, FRAME]:
             lines.append("\\hline")
 
         # Headers
         if options["header"]:
             lines.append(" & ".join(wanted_fields) + " \\\\")
-        if options["border"] and options["hrules"] in [ALL, HEADER]:
+        if (options["border"] or options["preserve_internal_border"]) and options[
+            "hrules"
+        ] in [ALL, HEADER]:
             lines.append("\\hline")
 
         # Data
@@ -2366,7 +2504,7 @@ def from_html_one(html_code, **kwargs):
     try:
         assert len(tables) == 1
     except AssertionError:
-        raise Exception(
+        raise ValueError(
             "More than one <table> in provided HTML code. Use from_html instead."
         )
     return tables[0]
